.. -*- coding: utf-8 -*-

.. _contents:

*************
Documentation
*************

==================
Cube squareui
==================

Data-centric user interface for cubicweb based on bootstrap

.. toctree::
   :maxdepth: 1

   html_page_header

   release_0.3.0.rst